@@ -32,6 +32,7 @@ from .drawables.linegl import LineGL
 from .drawables.meshgl import MeshGL
 from .drawables.pointgl import PointGL
 from .drawables.tubegl import TubeGL
+from .drawables.textgl import TextGL
 
 from .drawablefactory import DrawableFactory
 from .fpscounter import FPSCounter
@@ -70,6 +71,7 @@ class IntegrableViewer(QOpenGLWidget):
     signal_animation_finished = Signal()
 
     signal_screen_clicked = Signal(object)
+    signal_ray_generated = Signal(object)
     signal_fps_updated = Signal(float)
     signal_controller_updated = Signal(str)
     signal_projection_updated = Signal(str)
@@ -347,6 +349,9 @@ class IntegrableViewer(QOpenGLWidget):
     def tubes(self, *args, **kwargs) -> TubeGL:
         return self.register_drawable(self.factory.tubes(*args, **kwargs))
 
+    def text(self, *args, **kwargs) -> TextGL:
+        return self.register_drawable(self.factory.text(*args, **kwargs))
+
     """
     Load methods by path
     """
